@@ -4,20 +4,29 @@ from simple_orthanc.constants import  UNKNOWN, PARENT, ID
 from simple_orthanc.helpers import show_progress
 import json
 from copy import copy
-from dataclasses import dataclass, field
-from typing import List
+
+
 from itertools import chain
 import io
 
 
-@dataclass
-class DicomLevels:
-    Patients: List = field(default_factory=lambda: [])
-    Studies: list = field(default_factory=lambda: [])
-    Series: list = field(default_factory=lambda: [])
-    Instances: list = field(default_factory=lambda: [])
-    
-
+class DicomLevels:    
+    def __init__(self, Patients=None, Studies=None, Series=None,
+                 Instances=None):
+        if Patients is None:
+            Patients = []
+        if Studies is None:
+            Studies = []
+        if Series is None:
+            Series = []
+        if Instances is None:
+            Instances = []
+            
+        self.Patients = Patients
+        self.Series = Series
+        self.Studies = Studies
+        self.Instances = Instances
+            
     def __len__(self):
         return len(self.Patients) + len(self.Studies) + len(self.Series)\
             + len(self.Instances)
